==> embrace-android-sdk-3.0.8-sources.jar: io/embrace/android/embracesdk/Session.java <==
package io.embrace.android.embracesdk;

import com.google.gson.annotations.SerializedName;

import java.util.List;

/**
 * Represents a particular user's session within the app.
 */
class Session {
    /** A unique ID which identifies the session. */
    @SerializedName("id")
    private final String sessionId;

    /** The time that the session started. */
    @SerializedName("st")
    private final Long startTime;

    /** The time that the session ended. */
    @SerializedName("et")
    private final Long endTime;

    /** The ordinal of the session, starting from 0. */
    @SerializedName("sn")
    private final Integer number;

    @SerializedName("ht")
    private final Long lastHeartbeatTime;

    @SerializedName("tt")
    private final Long terminationTime;

    @SerializedName("ls")
    private final String lastState;

    @SerializedName("ba")
    private final Double startingBatteryLevel;

    @SerializedName("ce")
    private final Boolean endedCleanly;

    @SerializedName("tr")
    private final Boolean receivedTermination;

    @SerializedName("cs")
    private final Boolean coldStart;

    @SerializedName("ss")
    private final List<String> storyIds;

    @SerializedName("t")
    private final String sessionType;

    @SerializedName("il")
    private final List<String> infoLogIds;

    @SerializedName("el")
    private final List<String> errorLogIds;

    @SerializedName("wl")
    private final List<String> warningLogIds;

    public String getSessionId() {
        return sessionId;
    }

    public Long getStartTime() {
        return startTime;
    }

    public Long getEndTime() {
        return endTime;
    }

    public Integer getNumber() {
        return number;
    }

    public Long getLastHeartbeatTime() {
        return lastHeartbeatTime;
    }

    public Long getTerminationTime() {
        return terminationTime;
    }

    public String getLastState() {
        return lastState;
    }

    public Double getStartingBatteryLevel() {
        return startingBatteryLevel;
    }

    public Boolean isEndedCleanly() {
        return endedCleanly;
    }

    public Boolean isReceivedTermination() {
        return receivedTermination;
    }

    public Boolean isColdStart() {
        return coldStart;
    }

    public List<String> getStoryIds() {
        return storyIds;
    }

    public String getSessionType() {
        return sessionType;
    }

    public List<String> getInfoLogIds() {
        return infoLogIds;
    }

    public List<String> getErrorLogIds() {
        return errorLogIds;
    }

    public List<String> getWarningLogIds() {
        return warningLogIds;
    }

    private Session(Builder builder) {
        sessionId = builder.sessionId;
        startTime = builder.startTime;
        endTime = builder.endTime;
        number = builder.number;
        lastHeartbeatTime = builder.lastHeartbeatTime;
        terminationTime = builder.terminationTime;
        lastState = builder.lastState;
        startingBatteryLevel = builder.startingBatteryLevel;
        endedCleanly = builder.endedCleanly;
        receivedTermination = builder.receivedTermination;
        coldStart = builder.coldStart;
        storyIds = builder.storyIds;
        sessionType = builder.sessionType;
        infoLogIds = builder.infoLogIds;
        errorLogIds = builder.errorLogIds;
        warningLogIds = builder.warningLogIds;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    public static Builder newBuilder(Session copy) {
        Builder builder = new Builder();
        builder.sessionId = copy.getSessionId();
        builder.startTime = copy.getStartTime();
        builder.endTime = copy.getEndTime();
        builder.number = copy.getNumber();
        builder.lastHeartbeatTime = copy.getLastHeartbeatTime();
        builder.terminationTime = copy.getTerminationTime();
        builder.lastState = copy.getLastState();
        builder.startingBatteryLevel = copy.getStartingBatteryLevel();
        builder.endedCleanly = copy.isEndedCleanly();
        builder.receivedTermination = copy.isReceivedTermination();
        builder.coldStart = copy.isColdStart();
        builder.storyIds = copy.getStoryIds();
        builder.sessionType = copy.getSessionType();
        builder.infoLogIds = copy.getInfoLogIds();
        builder.errorLogIds = copy.getErrorLogIds();
        builder.warningLogIds = copy.getWarningLogIds();
        return builder;
    }


    public static final class Builder {
        private String sessionId;
        private Long startTime;
        private Long endTime;
        private Integer number;
        private Long lastHeartbeatTime;
        private Long terminationTime;
        private String lastState;
        private Double startingBatteryLevel;
        private Boolean endedCleanly;
        private Boolean receivedTermination;
        private Boolean coldStart;
        private List<String> storyIds;
        private String sessionType;
        private List<String> infoLogIds;
        private List<String> errorLogIds;
        private List<String> warningLogIds;

        private Builder() {
        }

        public Builder withSessionId(String sessionId) {
            this.sessionId = sessionId;
            return this;
        }

        public Builder withStartTime(Long startTime) {
            this.startTime = startTime;
            return this;
        }

        public Builder withEndTime(Long endTime) {
            this.endTime = endTime;
            return this;
        }

        public Builder withNumber(Integer number) {
            this.number = number;
            return this;
        }

        public Builder withLastHeartbeatTime(Long lastHeartbeatTime) {
            this.lastHeartbeatTime = lastHeartbeatTime;
            return this;
        }

        public Builder withTerminationTime(Long terminationTime) {
            this.terminationTime = terminationTime;
            return this;
        }

        public Builder withLastState(String lastState) {
            this.lastState = lastState;
            return this;
        }

        public Builder withStartingBatteryLevel(double startingBatteryLevel) {
            this.startingBatteryLevel = startingBatteryLevel;
            return this;
        }

        public Builder withEndedCleanly(boolean endedCleanly) {
            this.endedCleanly = endedCleanly;
            return this;
        }

        public Builder withReceivedTermination(boolean receivedTermination) {
            this.receivedTermination = receivedTermination;
            return this;
        }

        public Builder withColdStart(boolean coldStart) {
            this.coldStart = coldStart;
            return this;
        }

        public Builder withStoryIds(List<String> storyIds) {
            this.storyIds = storyIds;
            return this;
        }

        public Builder withSessionType(String sessionType) {
            this.sessionType = sessionType;
            return this;
        }

        public Builder withInfoLogIds(List<String> infoLogIds) {
            this.infoLogIds = infoLogIds;
            return this;
        }

        public Builder withErrorLogIds(List<String> errorLogIds) {
            this.errorLogIds = errorLogIds;
            return this;
        }

        public Builder withWarningLogIds(List<String> warningLogIds) {
            this.warningLogIds = warningLogIds;
            return this;
        }

        public Session build() {
            return new Session(this);
        }
    }
}

==> embrace-android-sdk-3.0.16-sources.jar: io/embrace/android/embracesdk/Session.java <==
package io.embrace.android.embracesdk;

import com.google.gson.annotations.SerializedName;

import java.util.List;

/**
 * Represents a particular user's session within the app.
 */
class Session {
    /** A unique ID which identifies the session. */
    @SerializedName("id")
    private final String sessionId;

    /** The time that the session started. */
    @SerializedName("st")
    private final Long startTime;

    /** The time that the session ended. */
    @SerializedName("et")
    private final Long endTime;

    /** The ordinal of the session, starting from 0. */
    @SerializedName("sn")
    private final Integer number;

    @SerializedName("ht")
    private final Long lastHeartbeatTime;

    @SerializedName("tt")
    private final Long terminationTime;

    @SerializedName("ls")
    private final String lastState;

    @SerializedName("ba")
    private final Double startingBatteryLevel;

    @SerializedName("ce")
    private final Boolean endedCleanly;

    @SerializedName("tr")
    private final Boolean receivedTermination;

    @SerializedName("cs")
    private final Boolean coldStart;

    @SerializedName("ss")
    private final List<String> storyIds;

    @SerializedName("t")
    private final String sessionType;

    @SerializedName("il")
    private final List<String> infoLogIds;

    @SerializedName("el")
    private final List<String> errorLogIds;

    @SerializedName("wl")
    private final List<String> warningLogIds;

    @SerializedName("cr")
    private final Boolean crashed;

    public String getSessionId() {
        return sessionId;
    }

    public Long getStartTime() {
        return startTime;
    }

    public Long getEndTime() {
        return endTime;
    }

    public Integer getNumber() {
        return number;
    }

    public Long getLastHeartbeatTime() {
        return lastHeartbeatTime;
    }

    public Long getTerminationTime() {
        return terminationTime;
    }

    public String getLastState() {
        return lastState;
    }

    public Double getStartingBatteryLevel() {
        return startingBatteryLevel;
    }

    public Boolean isEndedCleanly() {
        return endedCleanly;
    }

    public Boolean isReceivedTermination() {
        return receivedTermination;
    }

    public Boolean isColdStart() {
        return coldStart;
    }

    public List<String> getStoryIds() {
        return storyIds;
    }

    public String getSessionType() {
        return sessionType;
    }

    public List<String> getInfoLogIds() {
        return infoLogIds;
    }

    public List<String> getErrorLogIds() {
        return errorLogIds;
    }

    public List<String> getWarningLogIds() {
        return warningLogIds;
    }

    private Session(Builder builder) {
        sessionId = builder.sessionId;
        startTime = builder.startTime;
        endTime = builder.endTime;
        number = builder.number;
        lastHeartbeatTime = builder.lastHeartbeatTime;
        terminationTime = builder.terminationTime;
        lastState = builder.lastState;
        startingBatteryLevel = builder.startingBatteryLevel;
        endedCleanly = builder.endedCleanly;
        receivedTermination = builder.receivedTermination;
        coldStart = builder.coldStart;
        storyIds = builder.storyIds;
        sessionType = builder.sessionType;
        infoLogIds = builder.infoLogIds;
        errorLogIds = builder.errorLogIds;
        warningLogIds = builder.warningLogIds;
        crashed = builder.crashed;
    }

    public static Builder newBuilder() {
        return new Builder();
    }

    public static Builder newBuilder(Session copy) {
        Builder builder = new Builder();
        builder.sessionId = copy.getSessionId();
        builder.startTime = copy.getStartTime();
        builder.endTime = copy.getEndTime();
        builder.number = copy.getNumber();
        builder.lastHeartbeatTime = copy.getLastHeartbeatTime();
        builder.terminationTime = copy.getTerminationTime();
        builder.lastState = copy.getLastState();
        builder.startingBatteryLevel = copy.getStartingBatteryLevel();
        builder.endedCleanly = copy.isEndedCleanly();
        builder.receivedTermination = copy.isReceivedTermination();
        builder.coldStart = copy.isColdStart();
        builder.storyIds = copy.getStoryIds();
        builder.sessionType = copy.getSessionType();
        builder.infoLogIds = copy.getInfoLogIds();
        builder.errorLogIds = copy.getErrorLogIds();
        builder.warningLogIds = copy.getWarningLogIds();
        return builder;
    }


    public static final class Builder {
        private String sessionId;
        private Long startTime;
        private Long endTime;
        private Integer number;
        private Long lastHeartbeatTime;
        private Long terminationTime;
        private String lastState;
        private Double startingBatteryLevel;
        private Boolean endedCleanly;
        private Boolean receivedTermination;
        private Boolean coldStart;
        private List<String> storyIds;
        private String sessionType;
        private List<String> infoLogIds;
        private List<String> errorLogIds;
        private List<String> warningLogIds;
        private Boolean crashed;

        private Builder() {
        }

        public Builder withSessionId(String sessionId) {
            this.sessionId = sessionId;
            return this;
        }

        public Builder withStartTime(Long startTime) {
            this.startTime = startTime;
            return this;
        }

        public Builder withEndTime(Long endTime) {
            this.endTime = endTime;
            return this;
        }

        public Builder withNumber(Integer number) {
            this.number = number;
            return this;
        }

        public Builder withLastHeartbeatTime(Long lastHeartbeatTime) {
            this.lastHeartbeatTime = lastHeartbeatTime;
            return this;
        }

        public Builder withTerminationTime(Long terminationTime) {
            this.terminationTime = terminationTime;
            return this;
        }

        public Builder withLastState(String lastState) {
            this.lastState = lastState;
            return this;
        }

        public Builder withStartingBatteryLevel(double startingBatteryLevel) {
            this.startingBatteryLevel = startingBatteryLevel;
            return this;
        }

        public Builder withEndedCleanly(boolean endedCleanly) {
            this.endedCleanly = endedCleanly;
            return this;
        }

        public Builder withReceivedTermination(boolean receivedTermination) {
            this.receivedTermination = receivedTermination;
            return this;
        }

        public Builder withColdStart(boolean coldStart) {
            this.coldStart = coldStart;
            return this;
        }

        public Builder withStoryIds(List<String> storyIds) {
            this.storyIds = storyIds;
            return this;
        }

        public Builder withSessionType(String sessionType) {
            this.sessionType = sessionType;
            return this;
        }

        public Builder withInfoLogIds(List<String> infoLogIds) {
            this.infoLogIds = infoLogIds;
            return this;
        }

        public Builder withErrorLogIds(List<String> errorLogIds) {
            this.errorLogIds = errorLogIds;
            return this;
        }

        public Builder withWarningLogIds(List<String> warningLogIds) {
            this.warningLogIds = warningLogIds;
            return this;
        }

        public Builder withCrashed(boolean crashed) {
            this.crashed = crashed;
            return this;
        }

        public Session build() {
            return new Session(this);
        }
    }
}
